<?php

namespace App\Models;

use App\Models\Enums\AssetACL;
use App\Models\Scopes\CompanyScope;
use EloquentFilter\Filterable;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Auth;

/**
 * @method static \Illuminate\Database\Eloquent\Builder allowed()
 */
class Asset extends Model
{
    use HasFactory, Filterable;

    protected $fillable = [
        "name", "code", "description", "company_id", "status", "created_by",
        "owner", "address", "group_id", "geo_address_code", "acl",
        "whitelist", "latitude", "longitude"
    ];

    protected static function booted(): void
    {
        static::addGlobalScope(new CompanyScope);
    }

    public function scopeAllowed(Builder $query): void
    {
        $query->where(function (Builder $query) {
            return $query->where('acl', AssetACL::PRIVATE->value)->where('owner', Auth::id());
        })->orWhere(function (Builder $query) {
            return $query->where('acl', AssetACL::CUSTOM->value)->where('whitelist', 'like', '%' . Auth::id() . '%');
        });
    }
}
