<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\API;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "api" middleware group. Make something great!
|
*/


Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});

Route::post("/login", [API\AuthController::class, "login"]);

Route::middleware(['auth:sanctum'])->group(function () {
    Route::post("/logout", [API\AuthController::class, "logout"]);

    Route::apiResources([
        'asset-group' => API\AssetGroupController::class,
        'asset' => API\AssetController::class,
        'requirement-group' => API\RequirementGroupController::class,
        'requirement' => API\RequirementController::class,
        'project' => API\ProjectController::class,
    ]);

    Route::patch("project/{project}/closed", [API\ProjectController::class, "closed"])->name("project.closed");
    Route::patch("project/{project}/start", [API\ProjectController::class, "start"])->name("project.start");
    Route::patch("project/{project}/pause", [API\ProjectController::class, "pause"])->name("project.pause");
    Route::patch("project/{project}/postpone", [API\ProjectController::class, "postpone"])
        ->name("project.postpone");
    Route::patch("project/{project}/link-requirement", [API\ProjectController::class, "linkRequirement"])
        ->name("project.link-requirement");
    Route::patch("project/{project}/unlink-requirement", [API\ProjectController::class, "unlinkRequirement"])
        ->name("project.unlink-requirement");
    Route::patch("project/{project}/link-requirement-by-plan", [API\ProjectController::class, "linkRequirementByPlan"])
        ->name("project.link-requirement-by-plan");

    Route::get("project/{project}/plan", [API\ProjectController::class, "plan"])
        ->name("project.plan"); //项目关联计划
    Route::get("project/{project}/requirement", [API\ProjectController::class, "requirement"])
        ->name("project.requirement"); //项目需求
    Route::get("project/{project}/not-link-asset-requirement", [API\ProjectController::class, "notLinkAssetRequirement"])
        ->name("project.not-link-asset-requirement"); //项目未关联的资产需求
});
