<?php

namespace Tests\Feature\API;


use App\Models\AssetGroup;
use Tests\Feature\TestCase;

class AssetGroupTest extends TestCase
{
    public function test_asset_group_list()
    {
        AssetGroup::factory(30)->create();

        $response = $this->get(route('asset-group.index'));

        $response->assertStatus(200)
            ->assertJsonStructure([
                'data' => [
                    '*' => [
                        'name',
                        'sequence'
                    ]
                ]
            ]);
    }

    public function test_asset_group_create(): void
    {
        $response = $this->post(route('asset-group.store'), [
            'name' => 'test',
            'sequence' => 1,
        ]);

        $response->assertStatus(201);
    }

    public function test_asset_group_update(): void
    {
        $assetGroup = AssetGroup::factory()->create();

        $response = $this->put(route('asset-group.update', ['asset_group' => $assetGroup->id]), [
            'name' => 'test',
            'sequence' => 1,
        ]);

        $response->assertStatus(204);

        $newAssetGroup = AssetGroup::find($assetGroup->id);
        $this->assertEquals('test', $newAssetGroup->name);
        $this->assertEquals(1, $newAssetGroup->sequence);
    }

    public function test_asset_group_delete(): void
    {
        $assetGroup = AssetGroup::factory()->create();

        $response = $this->delete(route('asset-group.destroy', ['asset_group' => $assetGroup->id]));

        $response->assertStatus(204);

        $this->assertNull(AssetGroup::find($assetGroup->id));
    }
}
